@@ -1,7 +1,7 @@
-from typing import List, Union
+from typing import List, Union, Dict, Any
 
+# noinspection PyProtectedMember
 from pyspark import keyword_only
-from pyspark.ml.base import Transformer
 from pyspark.ml.param import Param
 from pyspark.sql.dataframe import DataFrame
 from pyspark.sql.utils import AnalysisException
@@ -9,35 +9,33 @@ from pyspark.sql.utils import AnalysisException
 from spark_pipeline_framework.logger.yarn_logger import get_logger
 from spark_pipeline_framework.progress_logger.progress_log_metric import ProgressLogMetric
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
+from spark_pipeline_framework.transformers.framework_transformer import FrameworkTransformer
 
 
-class FrameworkParquetLoader(Transformer):
+class FrameworkParquetLoader(FrameworkTransformer):
     # noinspection PyUnusedLocal
     @keyword_only
     def __init__(self,
                  view: str,
                  file_path: Union[str, List[str]],
                  name: str = None,
+                 parameters: Dict[str, Any] = None,
                  progress_logger: ProgressLogger = None,
                  merge_schema: bool = False,
                  limit: int = -1
                  ):
-        super(FrameworkParquetLoader, self).__init__()
+        super(FrameworkParquetLoader, self).__init__(name=name,
+                                                     parameters=parameters,
+                                                     progress_logger=progress_logger)
 
         self.logger = get_logger(__name__)
 
         self.view: Param = Param(self, "view", "")
         self._setDefault(view=view)  # type: ignore
 
-        self.name: Param = Param(self, "name", "")
-        self._setDefault(name=None)  # type: ignore
-
         self.file_path: Param = Param(self, "file_path", "")
         self._setDefault(file_path=None)  # type: ignore
 
-        self.progress_logger: Param = Param(self, "progress_logger", "")
-        self._setDefault(progress_logger=None)  # type: ignore
-
         self.merge_schema: Param = Param(self, "merge_schema", "")
         self._setDefault(merge_schema=None)  # type: ignore
 
@@ -53,9 +51,13 @@ class FrameworkParquetLoader(Transformer):
                   view: str,
                   file_path: Union[str, List[str]],
                   name: str = None,
-                  progress_logger: ProgressLogger = None
+                  parameters: Dict[str, Any] = None,
+                  progress_logger: ProgressLogger = None,
+                  merge_schema: bool = False,
+                  limit: int = -1
                   ):
         kwargs = self._input_kwargs  # type: ignore
+        super().setParams(name=name, parameters=parameters, progress_logger=progress_logger)
         return self._set(**kwargs)  # type: ignore
 
     def _transform(self, df: DataFrame) -> DataFrame:
@@ -101,24 +103,6 @@ class FrameworkParquetLoader(Transformer):
     def getFilePath(self) -> Union[str, List[str]]:
         return self.getOrDefault(self.file_path)  # type: ignore
 
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setName(self, value) -> 'FrameworkParquetLoader':
-        self._paramMap[self.name] = value  # type: ignore
-        return self
-
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getName(self) -> str:
-        return self.getOrDefault(self.name)  # type: ignore
-
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setProgressLogger(self, value) -> 'FrameworkParquetLoader':
-        self._paramMap[self.progress_logger] = value  # type: ignore
-        return self
-
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getProgressLogger(self) -> ProgressLogger:
-        return self.getOrDefault(self.progress_logger)  # type: ignore
-
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def setMergeSchema(self, value) -> 'FrameworkParquetLoader':
         self._paramMap[self.merge_schema] = value  # type: ignore
